Rename the dungeons.
[rogue-pphs.git] / main.c
diff --git a/main.c b/main.c
index 7e27bd3..f3626d8 100644 (file)
--- a/main.c
+++ b/main.c
@@ -1,7 +1,7 @@
 /*\r
  * @(#)main.c  3.27 (Berkeley) 6/15/81\r
  *\r
* Rogue: Exploring the Dungeons of Doom\r
  * Copyright (C) 1980, 1981 Michael Toy, Ken Arnold and Glenn Wichman\r
  * All rights reserved.\r
  *\r
@@ -88,9 +88,9 @@ char **envp;
        atoi(getenv("SEED")) :\r
        lowtime + getpid());\r
     if (wizard)\r
-       printf("Hello %s, welcome to dungeon #%d\n", whoami, dnum);\r
+       printf("Hello %s, welcome to cavern #%d\n", whoami, dnum);\r
     else\r
-       printf("Hello %s, just a moment while I dig the dungeon...\n", whoami);\r
+       printf("Hello %s, just a moment while I create the cavern...\n", whoami);\r
     fflush(stdout);\r
     seed = dnum;\r
     init_player();                     /* Roll up the rogue */\r
@@ -1,7 +1,7 @@
  * @(#)main.c  3.27 (Berkeley) 6/15/81\r
  *\r
- * Rogue: Exploring the Dungeons of Doom\r
+ * Rogue: Exploring the Cavern of Cuties\r
  * Copyright (C) 1980, 1981 Michael Toy, Ken Arnold and Glenn Wichman\r
  * All rights reserved.\r